## 0.0.1 - 2021-11-11

### Added

- New client methods:

  - `activate_survey`
  - `activate_tokens`
  - `add_participants`
  - `add_response`
  - `delete_participants`
  - `delete_survey`
  - `download_files`
  - `export_responses`
  - `export_responses_by_token`
  - `get_participant_properties`
  - `get_response_ids`
  - `get_site_settings`
  - `get_survey_properties`
  - `import_survey`
  - `list_participants`
  - `list_questions`
  - `list_surveys`
